@@ -9,6 +9,7 @@ from migrate.exceptions import MigrateDeprecationWarning
 from migrate.tests import fixture
 from migrate.tests.fixture.warnings import catch_warnings
 from migrate.versioning.util import *
+from migrate.versioning import api
 
 import warnings
 
@@ -19,15 +20,15 @@ class TestUtil(fixture.Pathed):
         url = 'sqlite://'
 
         engine = construct_engine(url)
-        self.assert_(engine.name == 'sqlite')
+        self.assertTrue(engine.name == 'sqlite')
 
         # keyword arg
         engine = construct_engine(url, engine_arg_encoding='utf-8')
-        self.assertEquals(engine.dialect.encoding, 'utf-8')
+        self.assertEqual(engine.dialect.encoding, 'utf-8')
 
         # dict
         engine = construct_engine(url, engine_dict={'encoding': 'utf-8'})
-        self.assertEquals(engine.dialect.encoding, 'utf-8')
+        self.assertEqual(engine.dialect.encoding, 'utf-8')
 
         # engine parameter
         engine_orig = create_engine('sqlite://')
@@ -37,14 +38,14 @@ class TestUtil(fixture.Pathed):
         # test precedance
         engine = construct_engine(url, engine_dict={'encoding': 'iso-8859-1'},
             engine_arg_encoding='utf-8')
-        self.assertEquals(engine.dialect.encoding, 'utf-8')
+        self.assertEqual(engine.dialect.encoding, 'utf-8')
 
         # deprecated echo=True parameter
         try:
-            # py 2.4 compatability :-/
+            # py 2.4 compatibility :-/
             cw = catch_warnings(record=True)
             w = cw.__enter__()
-            
+
             warnings.simplefilter("always")
             engine = construct_engine(url, echo='True')
             self.assertTrue(engine.echo)
@@ -63,6 +64,15 @@ class TestUtil(fixture.Pathed):
         # unsupported argument
         self.assertRaises(ValueError, construct_engine, 1)
 
+    def test_passing_engine(self):
+        repo = self.tmp_repos()
+        api.create(repo, 'temp')
+        api.script('First Version', repo)
+        engine = construct_engine('sqlite:///:memory:')
+
+        api.version_control(engine, repo)
+        api.upgrade(engine, repo)
+
     def test_asbool(self):
         """test asbool parsing"""
         result = asbool(True)
@@ -90,15 +100,15 @@ class TestUtil(fixture.Pathed):
         f.close()
 
         try:
-            # py 2.4 compatability :-/
+            # py 2.4 compatibility :-/
             cw = catch_warnings(record=True)
             w = cw.__enter__()
-            
+
             warnings.simplefilter("always")
 
             # deprecated spelling
             FakeFloat = load_model('test_load_model.FakeFloat')
-            self.assert_(isinstance(FakeFloat(), int))
+            self.assertTrue(isinstance(FakeFloat(), int))
 
             self.assertEqual(len(w),1)
             self.assertTrue(issubclass(w[-1].category,
@@ -107,15 +117,15 @@ class TestUtil(fixture.Pathed):
                 'model should be in form of module.model:User '
                 'and not module.model.User',
                 str(w[-1].message))
-            
+
         finally:
             cw.__exit__()
 
         FakeFloat = load_model('test_load_model:FakeFloat')
-        self.assert_(isinstance(FakeFloat(), int))
+        self.assertTrue(isinstance(FakeFloat(), int))
 
         FakeFloat = load_model(FakeFloat)
-        self.assert_(isinstance(FakeFloat(), int))
+        self.assertTrue(isinstance(FakeFloat(), int))
 
     def test_guess_obj_type(self):
         """guess object type from string"""
